@@ -839,7 +839,7 @@ nlme.formula <-
     } else {
       vW <- varWeights(nlmeSt$varStruct)
     }
-    work <- .C("fit_nlme",
+    work <- .C(fit_nlme,
 	       thetaPNLS = as.double(c(as.vector(unlist(sran)), sfix)),
                pdFactor = as.double(pdFactor(nlmeSt$reStruct)),
                as.integer(unlist(rev(grpShrunk))),
@@ -853,7 +853,7 @@ nlme.formula <-
 	       as.integer(!is.null(correlation)),
 	       as.integer(!is.null(weights)),
                nlModel,
-	       NAOK = TRUE, PACKAGE = "nlme")
+	       NAOK = TRUE)
     if (work$settings[4] == 1) {
       convResult <- 2
       if (controlvals$returnObject) {
