@@ -1,27 +1,7 @@
-### $Id: pdMat.R,v 1.6.2.3 2003/03/25 15:06:49 bates Exp $
-###
 ###              Classes of positive-definite matrices
 ###
-### Copyright 1997-2001  Jose C. Pinheiro <jcp@research.bell-labs.com>,
+### Copyright 1997-2003  Jose C. Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
-###
-### This file is part of the nlme library for S and related languages.
-### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
-### incorporated herein by reference.
-###
-### This program is distributed in the hope that it will be
-### useful, but WITHOUT ANY WARRANTY; without even the implied
-### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-### PURPOSE.  See the GNU General Public License for more
-### details.
-###
-### You should have received a copy of the GNU General Public
-### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
-
-##*## Generics that should be implemented for any pdMat class
 
 pdConstruct <-
   ## a virtual constructor for these objects
@@ -257,7 +237,7 @@ coef.pdMat <-
 }
 
 "coef<-.pdMat" <-
-  function(object, value)
+  function(object, ..., value)
 {
   value <- as.numeric(value)
   if (isInitialized(object)) {
@@ -632,11 +612,10 @@ pdFactor.pdSymm <-
   function(object)
 {
   Ncol <- round((-1 + sqrt(1 + 8 * length(object))) / 2)
-  .C("matrixLog_pd",
+  .C(matrixLog_pd,
      Factor = double(Ncol * Ncol),
      as.integer(Ncol),
-     as.double(object),
-     PACKAGE = "nlme")$Factor
+     as.double(object))$Factor
 }
 
 pdMatrix.pdSymm <-
@@ -760,10 +739,10 @@ pdFactor.pdLogChol <-
   function(object)
 {
   Ncol <- round((-1 + sqrt(1 + 8 * length(object))) / 2)
-  .C("logChol_pd",
+  .C(logChol_pd,
      Factor = double(Ncol * Ncol),
      as.integer(Ncol),
-     as.double(object), PACKAGE = "nlme")$Factor
+     as.double(object))$Factor
 }
 
 ####* Methods for standard generics
@@ -1166,11 +1145,10 @@ pdFactor.pdNatural <-
   function(object)
 {
   Ncol <- round((-1 + sqrt(1 + 8 * length(object))) / 2)
-  .C("natural_pd",
+  .C(natural_pd,
      Factor = double(Ncol * Ncol),
      as.integer(Ncol),
-     as.double(object),
-     PACKAGE = "nlme")$Factor
+     as.double(object))$Factor
 }
 
 pdMatrix.pdNatural <-
@@ -1629,11 +1607,10 @@ pdFactor.pdCompSymm <-
   function(object)
 {
   Ncol <- attr(object, "ncol")
-  .C("compSymm_pd",
+  .C(compSymm_pd,
      Factor = double(Ncol * Ncol),
      as.integer(Ncol),
-     as.double(object),
-     PACKAGE = "nlme")$Factor
+     as.double(object))$Factor
 }
 
 pdMatrix.pdCompSymm <-
@@ -1992,7 +1969,7 @@ coef.pdBlocked <-
 }
 
 "coef<-.pdBlocked" <-
-  function(object, value)
+  function(object, ..., value)
 {
   if (is.null(plen <- attr(object, "plen"))) {
     stop(paste("Cannot change the parameter when",
